.celldega-counter-button{background:linear-gradient(300deg,#93f 33.26%,#f66,#faca30,#00cd99,#0cf 86.29%);border-radius:10px;border:0;color:#fff;cursor:pointer;font-family:Roboto,sans-serif;font-size:2em;margin:10px;padding:10px 20px;transition:transform .25s ease-in-out}.celldega-counter-button:hover{transform:scale(1.05)}
